How to program *AWG Cores*
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. toctree:: 
    :maxdepth: 2

    notebooks/example3-1_SequenceParameters
    notebooks/example3-2_SimpleSequence
    notebooks/example3-3_PredefinedSequences